@@ -2,9 +2,9 @@ package gosec_test
 
 import (
 	"errors"
-	"io/ioutil"
 	"log"
 	"os"
+	"regexp"
 	"strings"
 
 	. "github.com/onsi/ginkgo/v2"
@@ -24,19 +24,19 @@ var _ = Describe("Analyzer", func() {
 	)
 	BeforeEach(func() {
 		logger, _ = testutils.NewLogger()
-		analyzer = gosec.NewAnalyzer(nil, tests, false, false, logger)
+		analyzer = gosec.NewAnalyzer(nil, tests, false, false, 1, logger)
 	})
 
 	Context("when processing a package", func() {
 		It("should not report an error if the package contains no Go files", func() {
 			analyzer.LoadRules(rules.Generate(false).RulesInfo())
-			dir, err := ioutil.TempDir("", "empty")
+			dir, err := os.MkdirTemp("", "empty")
 			defer os.RemoveAll(dir)
 			Expect(err).ShouldNot(HaveOccurred())
 			err = analyzer.Process(buildTags, dir)
 			Expect(err).ShouldNot(HaveOccurred())
 			_, _, errors := analyzer.Report()
-			Expect(len(errors)).To(Equal(0))
+			Expect(errors).To(BeEmpty())
 		})
 
 		It("should report an error if the package fails to build", func() {
@@ -49,9 +49,9 @@ var _ = Describe("Analyzer", func() {
 			err = analyzer.Process(buildTags, pkg.Path)
 			Expect(err).ShouldNot(HaveOccurred())
 			_, _, errors := analyzer.Report()
-			Expect(len(errors)).To(Equal(1))
+			Expect(errors).To(HaveLen(1))
 			for _, ferr := range errors {
-				Expect(len(ferr)).To(Equal(1))
+				Expect(ferr).To(HaveLen(1))
 			}
 		})
 
@@ -77,6 +77,29 @@ var _ = Describe("Analyzer", func() {
 			Expect(metrics.NumFiles).To(Equal(2))
 		})
 
+		It("should be able to analyze multiple Go files concurrently", func() {
+			customAnalyzer := gosec.NewAnalyzer(nil, true, true, false, 32, logger)
+			customAnalyzer.LoadRules(rules.Generate(false).RulesInfo())
+			pkg := testutils.NewTestPackage()
+			defer pkg.Close()
+			pkg.AddFile("foo.go", `
+				package main
+				func main(){
+					bar()
+				}`)
+			pkg.AddFile("bar.go", `
+				package main
+				func bar(){
+					println("package has two files!")
+				}`)
+			err := pkg.Build()
+			Expect(err).ShouldNot(HaveOccurred())
+			err = customAnalyzer.Process(buildTags, pkg.Path)
+			Expect(err).ShouldNot(HaveOccurred())
+			_, metrics, _ := customAnalyzer.Report()
+			Expect(metrics.NumFiles).To(Equal(2))
+		})
+
 		It("should be able to analyze multiple Go packages", func() {
 			analyzer.LoadRules(rules.Generate(false).RulesInfo())
 			pkg1 := testutils.NewTestPackage()
@@ -130,13 +153,19 @@ var _ = Describe("Analyzer", func() {
 			err = analyzer.Process(buildTags, pkg.Path)
 			Expect(err).ShouldNot(HaveOccurred())
 			_, _, errors := analyzer.Report()
-			Expect(len(errors)).To(Equal(1))
+			foundErr := false
 			for _, ferr := range errors {
-				Expect(len(ferr)).To(Equal(1))
+				Expect(ferr).To(HaveLen(1))
+				match, err := regexp.MatchString(ferr[0].Err, `expected declaration, found '}'`)
+				if !match || err != nil {
+					continue
+				}
+				foundErr = true
 				Expect(ferr[0].Line).To(Equal(4))
 				Expect(ferr[0].Column).To(Equal(5))
 				Expect(ferr[0].Err).Should(MatchRegexp(`expected declaration, found '}'`))
 			}
+			Expect(foundErr).To(BeTrue())
 		})
 
 		It("should not report errors when a nosec line comment is present", func() {
@@ -262,7 +291,7 @@ var _ = Describe("Analyzer", func() {
 			// overwrite nosec option
 			nosecIgnoreConfig := gosec.NewConfig()
 			nosecIgnoreConfig.SetGlobal(gosec.Nosec, "true")
-			customAnalyzer := gosec.NewAnalyzer(nosecIgnoreConfig, tests, false, false, logger)
+			customAnalyzer := gosec.NewAnalyzer(nosecIgnoreConfig, tests, false, false, 1, logger)
 			customAnalyzer.LoadRules(rules.Generate(false, rules.NewRuleFilter(false, "G401")).RulesInfo())
 
 			nosecPackage := testutils.NewTestPackage()
@@ -286,7 +315,7 @@ var _ = Describe("Analyzer", func() {
 			nosecIgnoreConfig := gosec.NewConfig()
 			nosecIgnoreConfig.SetGlobal(gosec.Nosec, "true")
 			nosecIgnoreConfig.SetGlobal(gosec.ShowIgnored, "true")
-			customAnalyzer := gosec.NewAnalyzer(nosecIgnoreConfig, tests, false, false, logger)
+			customAnalyzer := gosec.NewAnalyzer(nosecIgnoreConfig, tests, false, false, 1, logger)
 			customAnalyzer.LoadRules(rules.Generate(false, rules.NewRuleFilter(false, "G401")).RulesInfo())
 
 			nosecPackage := testutils.NewTestPackage()
@@ -379,7 +408,7 @@ var _ = Describe("Analyzer", func() {
 			// overwrite nosec option
 			nosecIgnoreConfig := gosec.NewConfig()
 			nosecIgnoreConfig.SetGlobal(gosec.NoSecAlternative, "#falsePositive")
-			customAnalyzer := gosec.NewAnalyzer(nosecIgnoreConfig, tests, false, false, logger)
+			customAnalyzer := gosec.NewAnalyzer(nosecIgnoreConfig, tests, false, false, 1, logger)
 			customAnalyzer.LoadRules(rules.Generate(false, rules.NewRuleFilter(false, "G401")).RulesInfo())
 
 			nosecPackage := testutils.NewTestPackage()
@@ -391,7 +420,7 @@ var _ = Describe("Analyzer", func() {
 			err = customAnalyzer.Process(buildTags, nosecPackage.Path)
 			Expect(err).ShouldNot(HaveOccurred())
 			nosecIssues, _, _ := customAnalyzer.Report()
-			Expect(nosecIssues).Should(HaveLen(0))
+			Expect(nosecIssues).Should(BeEmpty())
 		})
 
 		It("should ignore vulnerabilities when the default tag is found", func() {
@@ -402,7 +431,7 @@ var _ = Describe("Analyzer", func() {
 			// overwrite nosec option
 			nosecIgnoreConfig := gosec.NewConfig()
 			nosecIgnoreConfig.SetGlobal(gosec.NoSecAlternative, "#falsePositive")
-			customAnalyzer := gosec.NewAnalyzer(nosecIgnoreConfig, tests, false, false, logger)
+			customAnalyzer := gosec.NewAnalyzer(nosecIgnoreConfig, tests, false, false, 1, logger)
 			customAnalyzer.LoadRules(rules.Generate(false, rules.NewRuleFilter(false, "G401")).RulesInfo())
 
 			nosecPackage := testutils.NewTestPackage()
@@ -414,11 +443,11 @@ var _ = Describe("Analyzer", func() {
 			err = customAnalyzer.Process(buildTags, nosecPackage.Path)
 			Expect(err).ShouldNot(HaveOccurred())
 			nosecIssues, _, _ := customAnalyzer.Report()
-			Expect(nosecIssues).Should(HaveLen(0))
+			Expect(nosecIssues).Should(BeEmpty())
 		})
 
 		It("should be able to analyze Go test package", func() {
-			customAnalyzer := gosec.NewAnalyzer(nil, true, false, false, logger)
+			customAnalyzer := gosec.NewAnalyzer(nil, true, false, false, 1, logger)
 			customAnalyzer.LoadRules(rules.Generate(false).RulesInfo())
 			pkg := testutils.NewTestPackage()
 			defer pkg.Close()
@@ -443,7 +472,7 @@ var _ = Describe("Analyzer", func() {
 			Expect(issues).Should(HaveLen(1))
 		})
 		It("should be able to scan generated files if NOT excluded", func() {
-			customAnalyzer := gosec.NewAnalyzer(nil, true, false, false, logger)
+			customAnalyzer := gosec.NewAnalyzer(nil, true, false, false, 1, logger)
 			customAnalyzer.LoadRules(rules.Generate(false).RulesInfo())
 			pkg := testutils.NewTestPackage()
 			defer pkg.Close()
@@ -464,7 +493,7 @@ var _ = Describe("Analyzer", func() {
 			Expect(issues).Should(HaveLen(1))
 		})
 		It("should be able to skip generated files if excluded", func() {
-			customAnalyzer := gosec.NewAnalyzer(nil, true, true, false, logger)
+			customAnalyzer := gosec.NewAnalyzer(nil, true, true, false, 1, logger)
 			customAnalyzer.LoadRules(rules.Generate(false).RulesInfo())
 			pkg := testutils.NewTestPackage()
 			defer pkg.Close()
@@ -482,7 +511,7 @@ var _ = Describe("Analyzer", func() {
 			err = customAnalyzer.Process(buildTags, pkg.Path)
 			Expect(err).ShouldNot(HaveOccurred())
 			issues, _, _ := customAnalyzer.Report()
-			Expect(issues).Should(HaveLen(0))
+			Expect(issues).Should(BeEmpty())
 		})
 	})
 	It("should be able to analyze Cgo files", func() {
@@ -498,7 +527,7 @@ var _ = Describe("Analyzer", func() {
 		err = analyzer.Process(buildTags, testPackage.Path)
 		Expect(err).ShouldNot(HaveOccurred())
 		issues, _, _ := analyzer.Report()
-		Expect(issues).Should(HaveLen(0))
+		Expect(issues).Should(BeEmpty())
 	})
 
 	Context("when parsing errors from a package", func() {
@@ -520,9 +549,9 @@ var _ = Describe("Analyzer", func() {
 			err := analyzer.ParseErrors(pkg)
 			Expect(err).ShouldNot(HaveOccurred())
 			_, _, errors := analyzer.Report()
-			Expect(len(errors)).To(Equal(1))
+			Expect(errors).To(HaveLen(1))
 			for _, ferr := range errors {
-				Expect(len(ferr)).To(Equal(1))
+				Expect(ferr).To(HaveLen(1))
 				Expect(ferr[0].Line).To(Equal(1))
 				Expect(ferr[0].Column).To(Equal(2))
 				Expect(ferr[0].Err).Should(MatchRegexp(`build error`))
@@ -541,9 +570,9 @@ var _ = Describe("Analyzer", func() {
 			err := analyzer.ParseErrors(pkg)
 			Expect(err).ShouldNot(HaveOccurred())
 			_, _, errors := analyzer.Report()
-			Expect(len(errors)).To(Equal(1))
+			Expect(errors).To(HaveLen(1))
 			for _, ferr := range errors {
-				Expect(len(ferr)).To(Equal(1))
+				Expect(ferr).To(HaveLen(1))
 				Expect(ferr[0].Line).To(Equal(0))
 				Expect(ferr[0].Column).To(Equal(0))
 				Expect(ferr[0].Err).Should(MatchRegexp(`build error`))
@@ -562,9 +591,9 @@ var _ = Describe("Analyzer", func() {
 			err := analyzer.ParseErrors(pkg)
 			Expect(err).ShouldNot(HaveOccurred())
 			_, _, errors := analyzer.Report()
-			Expect(len(errors)).To(Equal(1))
+			Expect(errors).To(HaveLen(1))
 			for _, ferr := range errors {
-				Expect(len(ferr)).To(Equal(1))
+				Expect(ferr).To(HaveLen(1))
 				Expect(ferr[0].Line).To(Equal(0))
 				Expect(ferr[0].Column).To(Equal(0))
 				Expect(ferr[0].Err).Should(MatchRegexp(`build error`))
@@ -613,9 +642,9 @@ var _ = Describe("Analyzer", func() {
 			err := analyzer.ParseErrors(pkg)
 			Expect(err).ShouldNot(HaveOccurred())
 			_, _, errors := analyzer.Report()
-			Expect(len(errors)).To(Equal(1))
+			Expect(errors).To(HaveLen(1))
 			for _, ferr := range errors {
-				Expect(len(ferr)).To(Equal(2))
+				Expect(ferr).To(HaveLen(2))
 				Expect(ferr[0].Line).To(Equal(1))
 				Expect(ferr[0].Column).To(Equal(2))
 				Expect(ferr[0].Err).Should(MatchRegexp(`error1`))
@@ -646,7 +675,7 @@ var _ = Describe("Analyzer", func() {
 		It("should skip error for non-buildable packages", func() {
 			analyzer.AppendError("test", errors.New(`loading file from package "pkg/test": no buildable Go source files in pkg/test`))
 			_, _, errors := analyzer.Report()
-			Expect(len(errors)).To(Equal(0))
+			Expect(errors).To(BeEmpty())
 		})
 
 		It("should add a new error", func() {
@@ -662,16 +691,16 @@ var _ = Describe("Analyzer", func() {
 			Expect(err).ShouldNot(HaveOccurred())
 			analyzer.AppendError("file", errors.New("file build error"))
 			_, _, errors := analyzer.Report()
-			Expect(len(errors)).To(Equal(1))
+			Expect(errors).To(HaveLen(1))
 			for _, ferr := range errors {
-				Expect(len(ferr)).To(Equal(2))
+				Expect(ferr).To(HaveLen(2))
 			}
 		})
 	})
 
 	Context("when tracking suppressions", func() {
 		BeforeEach(func() {
-			analyzer = gosec.NewAnalyzer(nil, tests, false, true, logger)
+			analyzer = gosec.NewAnalyzer(nil, tests, false, true, 1, logger)
 		})
 
 		It("should not report an error if the violation is suppressed", func() {
